@@ -364,24 +364,45 @@ class InterpreterFunction(_function_base.SignedFunction):
       callkey = len(self._call_cache)
     return callkey
 
+  def _paramspec_signature(self, callable_type, substs):
+    # Unpack the paramspec substitution we have created in the matcher.
+    rhs = callable_type.formal_type_parameters[0]
+    if _isinstance(rhs, "Concatenate"):
+      r_pspec = rhs.paramspec
+      r_args = rhs.args
+    else:
+      r_pspec = rhs
+      r_args = ()
+    # TODO(b/217789659): Handle substs[] with multiple entries
+    data = substs[0].get(r_pspec.name)
+    if not data:
+      return
+    pspec_match = abstract_utils.get_atomic_value(data)
+    return_value = callable_type.formal_type_parameters[abstract_utils.RET]
+    return function.build_paramspec_signature(
+        pspec_match, r_args, return_value, self.ctx)
+
+  def _handle_paramspec(self, sig, annotations, substs, callargs):
+    if not sig.has_return_annotation:
+      return
+    retval = sig.annotations["return"]
+    if not (_isinstance(retval, "CallableClass") and retval.has_paramspec()):
+      return
+    ret_sig = self._paramspec_signature(retval, substs)
+    if ret_sig:
+      ret_annot = self.ctx.pytd_convert.signature_to_callable(ret_sig)
+      annotations["return"] = ret_annot
+    for name, _, annot in sig.iter_args(callargs):
+      if _isinstance(annot, "CallableClass") and annot.has_paramspec():
+        param_sig = self._paramspec_signature(annot, substs)
+        if param_sig:
+          param_annot = self.ctx.pytd_convert.signature_to_callable(param_sig)
+          annotations[name] = param_annot
+
   def call(self, node, func, args, alias_map=None, new_locals=False,
            frame_substs=()):
     if self.is_overload:
       raise function.NotCallable(self)
-    if (self.ctx.vm.is_at_maximum_depth() and
-        not self.name.endswith(".__init__")):
-      log.info("Maximum depth reached. Not analyzing %r", self.name)
-      self._set_callself_maybe_missing_members()
-      if (self.signature.has_return_annotation and
-          (self.ctx.options.always_use_return_annotations or
-           self.signature.annotations["return"] == self.ctx.convert.no_return)):
-        ret_type = self.signature.annotations["return"]
-        node, ret = self.ctx.vm.init_class(node, ret_type)
-        if self.is_coroutine():
-          ret = _instances.Coroutine(self.ctx, ret, node).to_variable(node)
-      else:
-        ret = self.ctx.new_unsolvable(node)
-      return node, ret
     args = self._fix_args_for_unannotated_contextmanager_exit(node, func, args)
     args = args.simplify(node, self.ctx, self.signature)
     sig, substs, callargs = self._find_matching_sig(node, args, alias_map)
@@ -391,6 +412,9 @@ class InterpreterFunction(_function_base.SignedFunction):
       callargs = self._map_args(node, args)
     self_arg = sig.get_self_arg(callargs)
     annotation_substs = substs
+    annotations = sig.annotations.copy()
+    # Fill in any ParamSpec vars in the annotations
+    self._handle_paramspec(sig, annotations, substs, args)
     # Adds type parameter substitutions from all containing classes. Note that
     # lower frames (ones closer to the end of self.ctx.vm.frames) take
     # precedence over higher ones.
@@ -400,7 +424,22 @@ class InterpreterFunction(_function_base.SignedFunction):
     # Keep type parameters without substitutions, as they may be needed for
     # type-checking down the road.
     annotations = self.ctx.annotation_utils.sub_annotations(
-        node, sig.annotations, annotation_substs, instantiate_unbound=False)
+        node, annotations, annotation_substs, instantiate_unbound=False)
+
+    if (self.ctx.vm.is_at_maximum_depth() and
+        not self.name.endswith(".__init__")):
+      log.info("Maximum depth reached. Not analyzing %r", self.name)
+      self._set_callself_maybe_missing_members()
+      if ("return" in annotations and
+          (self.ctx.options.always_use_return_annotations or
+           annotations["return"] == self.ctx.convert.no_return)):
+        ret_type = annotations["return"]
+        node, ret = self.ctx.vm.init_class(node, ret_type)
+        if self.is_coroutine():
+          ret = _instances.Coroutine(self.ctx, ret, node).to_variable(node)
+      else:
+        ret = self.ctx.new_unsolvable(node)
+      return node, ret
 
     first_arg = sig.get_first_arg(callargs)
     if first_arg and sig.has_return_annotation:
