@@ -4,7 +4,7 @@ import sys
 import textwrap
 
 from pytype import errors
-from pytype.directors import blocks
+from pytype.blocks import blocks
 from pytype.directors import directors
 from pytype.pyc import pyc
 import unittest
