@@ -534,7 +534,7 @@ class ErrorLog(ErrorLogBase):
     elif isinstance(t, abstract.Union):
       return self._join_printed_types(self._print_as_expected_type(o)
                                       for o in t.options)
-    elif abstract_utils.is_concrete(t):
+    elif t.is_concrete:
       return re.sub(r"(\\n|\s)+", " ",
                     typing.cast(mixin.PythonConstant, t).str_of_constant(
                         self._print_as_expected_type))
@@ -1459,6 +1459,11 @@ class ErrorLog(ErrorLogBase):
     msg = f"This enum case has already been covered: {case}."
     self.error(stack, msg, details=details)
 
+  @_error_name("paramspec-error")
+  def paramspec_error(self, stack, details=None):
+    msg = "ParamSpec error"
+    self.error(stack, msg, details=details)
+
 
 def get_error_names_set():
   return _ERROR_NAMES
